@@ -372,6 +372,76 @@ class WordPressAutoUpdater {
         }
     }
     
+    /**
+     * Check if updates are available for the requested types
+     * @param array $site The site data
+     * @param array $updatesToRun The update types to check
+     * @return array Array of update types that have available updates
+     */
+    private function checkAvailableUpdates($site, $updatesToRun) {
+        $availableUpdates = [];
+
+        foreach ($updatesToRun as $type) {
+            switch ($type) {
+                case 'core':
+                    try {
+                        $checkResult = $this->wpManager->executeWpCliCommand(
+                            $site['container_name'],
+                            $site['user'],
+                            "wp core check-update --format=json"
+                        );
+
+                        if ($checkResult['success']) {
+                            $updateInfo = json_decode($checkResult['output'], true);
+                            if (!empty($updateInfo)) {
+                                $availableUpdates[] = 'core';
+                                $this->log("Core updates available for {$site['domain']}", 'INFO');
+                            }
+                        }
+                    } catch (Exception $e) {
+                        $this->log("Failed to check core updates for {$site['domain']}: " . $e->getMessage(), 'ERROR');
+                    }
+                    break;
+
+                case 'plugins':
+                    try {
+                        $checkResult = $this->wpManager->executeWpCliCommand(
+                            $site['container_name'],
+                            $site['user'],
+                            "wp plugin list --update=available --format=count"
+                        );
+
+                        if ($checkResult['success'] && trim($checkResult['output']) !== '0') {
+                            $availableUpdates[] = 'plugins';
+                            $this->log("Plugin updates available for {$site['domain']}: " . trim($checkResult['output']) . " plugins", 'INFO');
+                        }
+                    } catch (Exception $e) {
+                        $this->log("Failed to check plugin updates for {$site['domain']}: " . $e->getMessage(), 'ERROR');
+                    }
+                    break;
+
+                case 'themes':
+                    try {
+                        $checkResult = $this->wpManager->executeWpCliCommand(
+                            $site['container_name'],
+                            $site['user'],
+                            "wp theme list --update=available --format=count"
+                        );
+
+                        if ($checkResult['success'] && trim($checkResult['output']) !== '0') {
+                            $availableUpdates[] = 'themes';
+                            $this->log("Theme updates available for {$site['domain']}: " . trim($checkResult['output']) . " themes", 'INFO');
+                        }
+                    } catch (Exception $e) {
+                        $this->log("Failed to check theme updates for {$site['domain']}: " . $e->getMessage(), 'ERROR');
+                    }
+                    break;
+            }
+        }
+
+        return $availableUpdates;
+    }
+
     /**
      * Process updates for a single site
      * @param array $site The site data
@@ -416,15 +486,25 @@ class WordPressAutoUpdater {
 
         $this->log("Updates to run for {$site['domain']}: " . implode(', ', $updatesToRun), 'INFO');
 
+        // Check if there are actually updates available before creating backup
+        $availableUpdates = $this->checkAvailableUpdates($site, $updatesToRun);
+
+        if (empty($availableUpdates)) {
+            $this->log("No updates available for {$site['domain']}, skipping backup and updates", 'INFO');
+            return true;
+        }
+
+        $this->log("Available updates for {$site['domain']}: " . implode(', ', $availableUpdates), 'INFO');
+
         // Create backup ONCE and wait for completion before ANY updates
         if (!$this->createAndWaitForBackup($site)) {
             $this->log("Skipping updates for {$site['domain']} due to backup failure", 'ERROR');
             return false;
         }
 
-        // Now run all the updates
+        // Now run only the updates that are actually available
         $success = true;
-        foreach ($updatesToRun as $type) {
+        foreach ($availableUpdates as $type) {
             switch ($type) {
                 case 'core':
                     if (!$this->updateCore($site)) {
