@@ -131,6 +131,25 @@ try {
             ob_clean(); // Clear buffer before output
             echo json_encode($result);
             exit;
+
+        case 'clone_site':
+            if (!check_permission('wordpress_install')) {
+                throw new Exception('Permission denied');
+            }
+
+            // Validate and sanitize input parameters
+            $sourceSiteId = filter_var($_POST['source_site_id'] ?? '', FILTER_VALIDATE_INT);
+            $targetSiteId = filter_var($_POST['target_site_id'] ?? '', FILTER_VALIDATE_INT);
+
+            if (!$sourceSiteId || !$targetSiteId) {
+                throw new Exception('Invalid site ID parameters');
+            }
+
+            // Additional security validation will be performed in cloneSite method
+            $result = $wpManager->cloneSite($sourceSiteId, $targetSiteId);
+            ob_clean(); // Clear buffer before output
+            echo json_encode($result);
+            exit;
             
         case 'search_replace':
             $result = $wpManager->searchReplace(
