@@ -54,14 +54,18 @@ try {
     // Include the WHP module functions
     require_once dirname(__FILE__) . '/whp.php';
     
+    // WHMCS stores username in plaintext but encrypts the password
+    $apiKey = $server->username;
+    $apiSecret = decrypt($server->password);
+    
     // Prepare parameters for SSO function
     $params = array(
         'serverdata' => array(
             'hostname' => $server->hostname,
             'port' => $server->port,
             'secure' => $server->secure == 'on',
-            'username' => decrypt($server->username),  // API Key (decrypt from WHMCS)
-            'password' => decrypt($server->password)   // API Secret (decrypt from WHMCS)
+            'username' => $apiKey,  // API Key (plaintext in DB)
+            'password' => $apiSecret   // API Secret (encrypted in DB, now decrypted)
         ),
         'username' => $service->username,
         'serviceid' => $serviceid
